<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/core/RUnit.cpp" line="+273"/>
        <source>None</source>
        <translation>Inget</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Inch</source>
        <translation>Tum</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Foot</source>
        <translation>Fot</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mile</source>
        <translation>Engelska mil</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Millimeter</source>
        <translation>Millimeter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Centimeter</source>
        <translation>Centimeter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Meter</source>
        <translation>Meter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Kilometer</source>
        <translation>Kilometer</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Microinch</source>
        <translation>Microtum</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mil</source>
        <translation>Mil</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Yard</source>
        <translation>Yard</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Angstrom</source>
        <translation>Ångström</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Nanometer</source>
        <translation>Nanometer</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Micron</source>
        <translation>Mikron</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decimeter</source>
        <translation>Decimeter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decameter</source>
        <translation>Dekameter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Hectometer</source>
        <translation>Hektometer</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Gigameter</source>
        <translation>Gigameter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Astro</source>
        <translation>Astro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Lightyear</source>
        <translation>Ljusår</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Parsec</source>
        <translation>Parsek</translation>
    </message>
</context>
<context>
    <name>RColor</name>
    <message>
        <location filename="../src/core/RColor.cpp" line="+288"/>
        <source>By Layer</source>
        <translation>Från lager</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>Från block</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Red</source>
        <translation>Röd</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Green</source>
        <translation>Grön</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Blue</source>
        <translation>Blå</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Cyan</source>
        <translation>Turkos</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Magenta</source>
        <translation>Magenta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Yellow</source>
        <translation>Gul</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Orange</source>
        <translation>Orange</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Red</source>
        <translation>Mörkröd</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Green</source>
        <translation>Mörkgrön</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Blue</source>
        <translation>Mörkblå</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Cyan</source>
        <translation>Mörkturkos</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Magenta</source>
        <translation>Mörk magenta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Yellow</source>
        <translation>Mörkgul</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Black</source>
        <translation>Svart</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gray</source>
        <translation>Grå</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Light Gray</source>
        <translation>Ljusgrå</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>White</source>
        <translation>Vit</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Others...</source>
        <translation>Andra...</translation>
    </message>
</context>
<context>
    <name>RDocumentVariables</name>
    <message>
        <location filename="../src/core/RDocumentVariables.cpp" line="+45"/>
        <source>Current Layer ID</source>
        <translation>Aktuellt lager ID</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drawing Unit</source>
        <translation>Ritenhet</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation>Linjetypsskala</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimension Font</source>
        <translation>Dimension Typsnitt</translation>
    </message>
</context>
<context>
    <name>REntity</name>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="+92"/>
        <source>Block</source>
        <translation>Block</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+73"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Position</source>
        <translation>Position</translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="+65"/>
        <source>Pixel Unit</source>
        <translation>Pixel-enhet</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="+82"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+72"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-2"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Origin</source>
        <translation>Origo</translation>
    </message>
    <message>
        <location line="-1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
        <location line="+10"/>
        <source>Z</source>
        <translation>Z</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layout</source>
        <translation>Layout</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-7"/>
        <source>Scale</source>
        <translation>Skala</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angle</source>
        <translation>Vinkel</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Columns</source>
        <translation>Kolumner</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Rows</source>
        <translation>Rader</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Column Spacing</source>
        <translation>Kolumnavstånd</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Row Spacing</source>
        <translation>Radavstånd</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Attributes</source>
        <translation>Attribut</translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="+91"/>
        <location filename="../src/core/RObject.cpp" line="+67"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Block ID</source>
        <translation>Block ID</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layer</source>
        <translation>Lager</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+102"/>
        <source>Linetype</source>
        <translation>Linjetyp</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation>Linjetyp Skala</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+1"/>
        <source>Lineweight</source>
        <translation>Linjetjocklek</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="-2"/>
        <source>Color</source>
        <translation>Färg</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Displayed Color</source>
        <translation>Visad Färg</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Draw Order</source>
        <translation>Ritordning</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Boundary</source>
        <translation>Gräns</translation>
    </message>
    <message>
        <location line="-3"/>
        <location filename="../src/core/RLayout.cpp" line="+3"/>
        <source>Left</source>
        <translation>Vänster</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Bottom</source>
        <translation>Nederkant</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Right</source>
        <translation>Höger</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Top</source>
        <translation>Överkant</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <source>Size</source>
        <translation>Storlek</translation>
    </message>
    <message>
        <location line="-1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-2"/>
        <source>Width</source>
        <translation>Bredd</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+1"/>
        <source>Height</source>
        <translation>Höjd</translation>
    </message>
    <message>
        <location filename="../src/core/RObject.cpp" line="-1"/>
        <location filename="../src/core/RPropertyTypeId.cpp" line="+151"/>
        <source>Custom</source>
        <translation>Anpassad</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Handle</source>
        <translation>Handtag</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Protected</source>
        <translation>Skyddad</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/RTextBasedEntity.cpp" line="-3"/>
        <source>Simple</source>
        <translation>Enkel</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Text Position</source>
        <translation>Textplacering</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plain Text</source>
        <translation>Oformaterad text</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Font Name</source>
        <translation>Typsnittsnamn</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Height</source>
        <translation>Texthöjd</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Angle</source>
        <translation>Textvinkel</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>X Scale</source>
        <translation>X-skala</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bold</source>
        <translation>Fet</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Italic</source>
        <translation>Kursiv</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Line Spacing</source>
        <translation>Radavstånd</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>Alignment</source>
        <translation>Justering</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Horizontal</source>
        <translation>Horisontell</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Vertical</source>
        <translation>Vertikal</translation>
    </message>
    <message>
        <location filename="../src/core/RViewportEntity.cpp" line="+2"/>
        <source>Rotation</source>
        <translation>Rotation</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>On</source>
        <translation>På</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Center</source>
        <translation>Vy-centrum</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Target</source>
        <translation>Vy - mål</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Overall</source>
        <translation>Övergripande</translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="-6"/>
        <location filename="../src/core/RLayer.cpp" line="-8"/>
        <location filename="../src/core/RLayerState.cpp" line="+46"/>
        <location filename="../src/core/RLayout.cpp" line="-24"/>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hidden</source>
        <translation>Dold</translation>
    </message>
    <message>
        <location filename="../src/core/RLayer.cpp" line="+1"/>
        <source>Off</source>
        <translation>Av</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Frozen</source>
        <translation>Fryst</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Locked</source>
        <translation>Låst</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Collapsed</source>
        <translation>Kollapsad</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plottable</source>
        <translation>Plottningsbar</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Snappable</source>
        <translation>Snäppbar</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Off is Freeze</source>
        <translation>Av är fryst</translation>
    </message>
    <message>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Tab Order</source>
        <translation>Flikordning</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Limits</source>
        <translation>Min-gränser</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Limits</source>
        <translation>Max-gränser</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Insertion Base</source>
        <translation type="unfinished">Införande</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Extents</source>
        <translation>Min utsträckning</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Extents</source>
        <translation>Max utsträckning</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceData.cpp" line="+655"/>
        <source>Circular (recursive) block referencing detected:</source>
        <translation>Detekterat cirkulärt beroende mellan block:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block name:</source>
        <translation>Blocknamn:</translation>
    </message>
</context>
<context>
    <name>RGuiAction</name>
    <message>
        <location filename="../src/core/RGuiAction.cpp" line="+186"/>
        <source>Requires selection</source>
        <translation>Kräver markering</translation>
    </message>
</context>
<context>
    <name>RLayer</name>
    <message>
        <source>Name</source>
        <translation type="vanished">Namn</translation>
    </message>
    <message>
        <source>Hidden</source>
        <translation type="vanished">Dold</translation>
    </message>
    <message>
        <source>Locked</source>
        <translation type="vanished">Låst</translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="vanished">Färg</translation>
    </message>
    <message>
        <source>Linetype</source>
        <translation type="vanished">Linjetyp</translation>
    </message>
    <message>
        <source>Lineweight</source>
        <translation type="vanished">Linjetjocklek</translation>
    </message>
</context>
<context>
    <name>RLinetype</name>
    <message>
        <location filename="../src/core/RLinetype.cpp" line="+48"/>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Description</source>
        <translation>Beskrivning</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Metric</source>
        <translation>Metrisk</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pattern</source>
        <translation>Mönster</translation>
    </message>
</context>
<context>
    <name>RLinetypePattern</name>
    <message>
        <location filename="../src/core/RLinetypePattern.cpp" line="+856"/>
        <source>By Layer</source>
        <translation>Från Lager</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>Från Block</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Continuous</source>
        <translation>Kontinuerlig</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Border</source>
        <translation>Kant</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Center</source>
        <translation>Mittpunkt</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dash dot</source>
        <translation>Streck prick</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dashed</source>
        <translation>Streckad</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Divide</source>
        <translation>Dividera</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dot</source>
        <translation>Punkt</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Hidden</source>
        <translation>Dold</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Phantom</source>
        <translation>Skugga</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>ISO dash</source>
        <translation>ISO streck</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash space</source>
        <translation>ISO streck blanksteg</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash dot</source>
        <translation>ISO långt streck punkt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-dot</source>
        <translation>ISO långt streck dubbelpunkt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash triple-dot</source>
        <translation>ISO långt streck trippelpunkt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dot</source>
        <translation>ISO punkt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash short-dash</source>
        <translation>ISO långt streck kort streck</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-short-dash</source>
        <translation>ISO långt streck dubbel kort streck</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash dot</source>
        <translation>ISO streck punkt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash dot</source>
        <translation>ISO dubbelstreck punkt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash double-dot</source>
        <translation>ISO streck dubbelpunkt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash double-dot</source>
        <translation>ISO dubbelstreck dubbelpunkt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash triple-dot</source>
        <translation>ISO streck trippelpunkt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash triple-dot</source>
        <translation>ISO dubbelstreck trippelpunkt</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Hot Water Supply</source>
        <translation>Varmvattenförsörjning</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hot Water</source>
        <translation>Varmvatten</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gas Line</source>
        <translation>Gasledning</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Batting</source>
        <translation>Isolering</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Zig Zag</source>
        <translation>Sicksack</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Tracks</source>
        <translation>Spår</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 1</source>
        <translation>Gränslinje 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 2</source>
        <translation>Gränslinje 2</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Drainage</source>
        <translation>Dränering</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drainage Reversed</source>
        <translatorcomment>Say what now? word to word translation here. I have no idéa what reversed drainage is..</translatorcomment>
        <translation>Omvänd dränering</translation>
    </message>
</context>
<context>
    <name>RLineweight</name>
    <message>
        <location filename="../src/core/RLineweight.cpp" line="+35"/>
        <source>By Layer</source>
        <translation>Från lager</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>Från block</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.00mm</source>
        <translation>0.00mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.05mm</source>
        <translation>0.05mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.09mm</source>
        <translation>0.09mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.13mm (ISO)</source>
        <translation>0.13mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.15mm</source>
        <translation>0.15mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.18mm (ISO)</source>
        <translation>0.18mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.20mm</source>
        <translation>0.20mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.25mm (ISO)</source>
        <translation>0.25mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.30mm</source>
        <translation>0.30mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.35mm (ISO)</source>
        <translation>0.35mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.40mm</source>
        <translation>0.40mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.50mm (ISO)</source>
        <translation>0.50mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.53mm</source>
        <translation>0.53mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.60mm</source>
        <translation>0.60mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.70mm (ISO)</source>
        <translation>0.70mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.80mm</source>
        <translation>0.80mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.90mm</source>
        <translation>0.90mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.00mm (ISO)</source>
        <translation>1.00mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.06mm</source>
        <translation>1.06mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.20mm</source>
        <translation>1.20mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.40mm (ISO)</source>
        <translation>1.40mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.58mm</source>
        <translation>1.58mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.00mm (ISO)</source>
        <translation>2.00mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.11mm</source>
        <translation>2.11mm</translation>
    </message>
</context>
<context>
    <name>RObject</name>
    <message>
        <source>Custom</source>
        <translation type="vanished">Anpassad</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="vanished">Typ</translation>
    </message>
    <message>
        <source>Handle</source>
        <translation type="vanished">Alias</translation>
    </message>
    <message>
        <source>Protected</source>
        <translation type="vanished">Skyddad</translation>
    </message>
</context>
</TS>
